/*
** File: avr.c  
** Project: ADB3 API library
** Purpose: OS-independent code for ADB3 API library, AVR extension.
**
** (C) Copyright Alpha Data 2016
*/

#include <adb3/avr.h>
#include <portability.h>
#include <adb3_platform.h>
#include "ioctl_adb3.h"

ADB3_EXPORT ADB3_STATUS
ADB3_CALLING_CONVENTION
ADB3_CommandAVR(
  ADB3_HANDLE hCard,
  _ADB3_UINT32 flags,
  _ADB3_UINT32 timeoutUs,
  _ADB3_UINT32 commandLength,
  const _ADB3_UINT8* pCommand,
  _ADB3_UINT32 responseLength,
  _ADB3_UINT8* pResponse,
  _ADB3_UINT32* pActualResponseLength)
{
  IOCTLS_ADB3_COMMANDAVR ioctl;
  ADB3_STATUS status;

  ioctl.in.flags = flags;
  ioctl.in.timeoutUs = timeoutUs;
  ioctl.in.commandLength = commandLength;
  ioctl.in.pCommand = pCommand;
  ioctl.in.responseLength = responseLength;
  ioctl.in.pResponse = pResponse;
  status = adb3Ioctl(hCard, ADB3_IOCTLCODE_COMMANDAVR, &ioctl, sizeof(ioctl.in), sizeof(ioctl.out));
  if (ADB3_SUCCESS == status) {
    if (NULL != pActualResponseLength) {
      *pActualResponseLength = ioctl.out.actualResponseLength;
    }
  }
  return status;
}

ADB3_EXPORT ADB3_STATUS
ADB3_CALLING_CONVENTION
ADB3_GetAVRStatus(
  ADB3_HANDLE hCard,
  ADB3_AVR_STATUS* pAVRStatus)
{
  IOCTLS_ADB3_GETAVRSTATUS ioctl;
  ADB3_STATUS status;

  if (NULL == pAVRStatus) {
    return ADB3_NULL_POINTER;
  }

  status = adb3Ioctl(hCard, ADB3_IOCTLCODE_GETAVRSTATUS, &ioctl, 0, sizeof(ioctl.out));
  if (ADB3_SUCCESS == status) {
    pAVRStatus->AsUINT32 = ioctl.out.asUint32;
  }
  return status;
}
